@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kget_linkview.h 191055 2002-11-29 10:21:30Z pfeiffer $
+** $Id: kget_linkview.h 435719 2005-07-17 22:44:08Z pino $
 **
 ** Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
 **
@@ -33,15 +33,16 @@ public:
     ~KGetLinkView();
 
     void setLinks( QPtrList<LinkItem>& links );
+    void setPageURL( const QString& url );
 
 signals:
     void leechURLs( const KURL::List& urls );
 
 private slots:
     void slotStartLeech();
+    void slotSelectAll();
 
 private:
-    void initView();
     void showLinks( const QPtrList<LinkItem>& links );
 
     QPtrList<LinkItem> m_links;
