@@ -1,7 +1,7 @@
 /*
     chatmessagepart.cpp - Chat Message KPart
 
-    Copyright (c) 2002-2005 by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Olivier Goffart       <ogoffart @ kde.org>
     Copyright (c) 2002-2003 by Martijn Klingens      <klingens@kde.org>
     Copyright (c) 2004      by Richard Smith         <kde@metafoo.co.uk>
 
@@ -48,7 +48,7 @@
 
 #include "chatmemberslistwidget.h"
 #include "kopetechatwindow.h"
-#include "kopetemessagemanager.h"
+#include "kopetechatsession.h"
 #include "kopetemetacontact.h"
 #include "kopetepluginmanager.h"
 #include "kopeteprefs.h"
@@ -101,6 +101,7 @@ public:
 	 */
 	QTimer refreshtimer;
 	bool transformAllMessages;
+	ToolTip *tt;
 };
 
 class ChatMessagePart::ToolTip : public QToolTip
@@ -185,7 +186,7 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, QWidget *parent, con
 
 	view()->setFocusPolicy( QWidget::NoFocus );
 
-	new ToolTip( this );
+	d->tt=new ToolTip( this );
 
 	// It is not possible to drag and drop on our widget
 	view()->setAcceptDrops(false);
@@ -230,6 +231,7 @@ ChatMessagePart::~ChatMessagePart()
 		delete backgroundFile;
 	}
 
+	delete d->tt;
 	delete d->xsltParser;
 	delete d;
 }
@@ -256,7 +258,7 @@ void ChatMessagePart::save()
 	KTempFile tempFile;
 	tempFile.setAutoDelete( true );
 	QFile* file = tempFile.file();
-	
+
 	QTextStream stream ( file );
 	if ( dlg.currentFilter() == QString::fromLatin1( "text/xml" ) )
 	{
@@ -279,9 +281,9 @@ void ChatMessagePart::save()
 	{
 		stream << htmlDocument().toHTML() << '\n';
 	}
-	
+
 	tempFile.close();
-	
+
 	if ( !KIO::NetAccess::move( KURL( tempFile.name() ), saveURL ) )
 	{
 		KMessageBox::queuedMessageBox( view(), KMessageBox::Error,
@@ -376,7 +378,7 @@ void ChatMessagePart::appendMessage( Kopete::Message &message )
 		while ( bufferLen>0 && messageMap.count() >= bufferLen )
 		{
 			htmlDocument().body().removeChild( htmlDocument().body().firstChild() );
-			messageMap.remove( messageMap.begin() );
+			messageMap.pop_front();
 		}
 
 		if ( !scrollPressed )
