@@ -38,9 +38,9 @@ class KopeteRichTextEditPart : public KParts::ReadOnlyPart
 
 		QFont font() { return mFont; }
 
-		QColor fgColor() { return mFgColor; }
+		QColor fgColor();
 
-		QColor bgColor() { return mBgColor; }
+		QColor bgColor();
 
 		void clear();
 
@@ -66,6 +66,8 @@ class KopeteRichTextEditPart : public KParts::ReadOnlyPart
 		void setFont( const QFont & );
 		void setFont( const QString & );
 
+		void setFontSize( int );
+
 		void setUnderline( bool );
 		void setBold( bool );
 		void setItalic( bool );
@@ -76,6 +78,7 @@ class KopeteRichTextEditPart : public KParts::ReadOnlyPart
 		void setAlignJustify( bool yes );
 
 		void checkToolbarEnabled();
+		void reloadConfig();
 
 	signals:
 		void toggleToolbar( bool enabled );
@@ -127,6 +130,8 @@ class KopeteRichTextEditPart : public KParts::ReadOnlyPart
 		bool m_richTextAvailable;
 		bool m_richTextEnabled;
 
+		bool m_configWriteLock;
+
 		QFont mFont;
 		QColor mBgColor;
 		QColor mFgColor;
