@@ -1,5 +1,5 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2003 Olivier Goffart <ogoffart@tiscalinet.be>
+    Copyright (C) 2003 Olivier Goffart <ogoffart @ kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -22,7 +22,7 @@
 
 #include <kcmodule.h>
 
-#include <kopete_export.h>
+#include "kopete_export.h"
 
 class KAutoConfig;
 class KConfig;
@@ -65,12 +65,23 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
 		KCAutoConfigModule( KInstance * instance, QWidget * parent = 0, const QStringList & args = QStringList() );
 
 		/**
+		*  Constructor.
 		*  @param config the KConfig to use
+		*  @param instance KInstance object for this KCM
+		*  @param parent parent widget
+		*  @param args special arguments for this KCM
+		*
+		*  @todo document what the args mean (inherited from KCModule?)
 		*/
 		KCAutoConfigModule(KConfig* config, KInstance * instance, QWidget * parent = 0, const QStringList & args = QStringList() );
 
 		/**
+		*  Constructor, much like the one above, except with
+		*  no instance and with a name.
 		*  @param config the KConfig to use
+		*  @param parent parent widget
+		*  @param name name of the object
+		*  @param args special arguments for this KCM
 		*/
 		KCAutoConfigModule(KConfig* config, QWidget * parent = 0, const char * name=0 , const QStringList & args = QStringList() );
 
