@@ -31,6 +31,7 @@
 #include <klocale.h>
 #include <kpopupmenu.h>
 #include <kmessagebox.h>
+#include <klistviewsearchline.h>
 
 #include "kopetecontactlist.h"
 #include "kopeteglobal.h"
@@ -38,10 +39,11 @@
 #include "kopeteprotocol.h"
 #include "kopeteaccount.h"
 #include "kopetestdaction.h"
-#include "kopetemessagemanager.h"
+#include "kopetechatsession.h"
 #include "kopeteview.h"
 #include "kopetemetacontact.h"
 #include "kopeteprefs.h"
+#include "metacontactselectorwidget.h"
 
 //For the moving to another metacontact dialog
 #include <qlabel.h>
@@ -51,6 +53,7 @@
 #include <klistview.h>
 #include <qcheckbox.h>
 #include <qwhatsthis.h>
+#include <qstylesheet.h>
 
 namespace Kopete {
 
@@ -100,8 +103,8 @@ Contact::Contact( Account *account, const QString &contactId,
 
 		parent->addContact( this );
 	}
-
-	connect( account, SIGNAL( isConnectedChanged() ), SLOT( slotAccountIsConnectedChanged() ) );
+	if( account )
+		connect( account, SIGNAL( isConnectedChanged() ), SLOT( slotAccountIsConnectedChanged() ) );
 }
 
 Contact::~Contact()
@@ -184,11 +187,6 @@ void Contact::slotAddContact()
 
 KPopupMenu* Contact::popupMenu( ChatSession *manager )
 {
-	// FIXME:
-	// This should perhaps be KActionCollection * Contact::contactActions()
-	// to avoid passing around KPopupMenu's (Jason)
-	//
-
 	// Build the menu
 	KPopupMenu *menu = new KPopupMenu();
 
@@ -265,44 +263,19 @@ void Contact::changeMetaContact()
 		KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true );
 
 	QVBox *w = new QVBox( moveDialog );
-	w->setSpacing( 8 );
-        new QLabel( i18n( "Select the meta contact to which you want to move this contact:" ), w );
-	KListView *selectMetaContactListBox = new KListView ( w, "selectMetaContactListBox" );
-	selectMetaContactListBox->addColumn( i18n( "Display Name" ) );
-	selectMetaContactListBox->addColumn( i18n( "Contact IDs" ) );
-
-	QMap<QListViewItem*,MetaContact*> map;
-	QPtrList<MetaContact> metaContacts = ContactList::self()->metaContacts();
-	for( MetaContact *mc = metaContacts.first(); mc ; mc = metaContacts.next() )
-	{
-		if( !mc->isTemporary() && mc != metaContact() )
-		{
-			QString t;
-			bool f=true;
-			QPtrList<Contact> contacts = mc->contacts();
-			for( Contact *c = contacts.first(); c ; c = contacts.next() )
-			{
-				if( !f )
-					t += QString::fromLatin1( " ; " );
-				t += c->contactId();
-				f = false;
-			}
-
-			map.insert(  new QListViewItem(selectMetaContactListBox, mc->displayName(),t) , mc  ) ;
-		}
-	}
-
-	selectMetaContactListBox->sort();
+	w->setSpacing( KDialog::spacingHint() );
+	Kopete::UI::MetaContactSelectorWidget *selector = new Kopete::UI::MetaContactSelectorWidget(w);
+	selector->setLabelMessage(i18n( "Select the meta contact to which you want to move this contact:" ));
 
 	QCheckBox *chkCreateNew = new QCheckBox( i18n( "Create a new metacontact for this contact" ), w );
 	QWhatsThis::add( chkCreateNew , i18n( "If you select this option, a new metacontact will be created in the top-level group "
 		"with the name of this contact and the contact will be moved to it." ) );
-	QObject::connect( chkCreateNew , SIGNAL( toggled(bool) ) ,  selectMetaContactListBox , SLOT ( setDisabled(bool) ) ) ;
+	QObject::connect( chkCreateNew , SIGNAL( toggled(bool) ) ,  selector , SLOT ( setDisabled(bool) ) ) ;
 
-	moveDialog->setMainWidget( w );
+	moveDialog->setMainWidget(w);
 	if( moveDialog->exec() == QDialog::Accepted )
 	{
-		Kopete::MetaContact *mc = map[selectMetaContactListBox->currentItem()];
+		Kopete::MetaContact *mc = selector->metaContact();
 		if(chkCreateNew->isChecked())
 		{
 			mc=new Kopete::MetaContact();
@@ -333,7 +306,7 @@ void Contact::setMetaContact( MetaContact *m )
 			result = KMessageBox::questionYesNoCancel( Kopete::UI::Global::mainWidget(), i18n( "You are moving the contact `%1' to the meta contact `%2'.\n"
 				"`%3' will be empty afterwards. Do you want to delete this contact?" )
 					.arg(contactId(), m ? m->displayName() : QString::null, old->displayName())
-				, i18n( "Move Contact" ), i18n( "&Delete" ) , i18n( "&Keep" ) , QString::fromLatin1("delete_old_contact_when_move") );
+				, i18n( "Move Contact" ), KStdGuiItem::del(), i18n( "&Keep" ) , QString::fromLatin1("delete_old_contact_when_move") );
 			if(result==KMessageBox::Cancel)
 				return;
 		}
@@ -476,7 +449,8 @@ void Contact::slotDelete()
 {
 	if ( KMessageBox::warningContinueCancel( Kopete::UI::Global::mainWidget(),
 		i18n( "Are you sure you want to remove the contact  '%1' from your contact list?" ).
-		arg( d->contactId ), i18n( "Remove Contact" ), KGuiItem(i18n("Remove"), QString::fromLatin1("editdelete") ) )
+		arg( d->contactId ), i18n( "Remove Contact" ), KGuiItem(i18n("Remove"), QString::fromLatin1("editdelete") ),
+		QString::fromLatin1("askRemoveContact"), KMessageBox::Notify | KMessageBox::Dangerous )
 		== KMessageBox::Continue )
 	{
 		deleteContact();
@@ -571,12 +545,17 @@ unsigned long int Contact::idleTime() const
 
 void Contact::setIdleTime( unsigned long int t )
 {
+	bool idleChanged = false;
+	if(d->idleTime != t)
+		idleChanged = true;
 	d->idleTime=t;
 	if(t > 0)
 		d->idleTimer.start();
-	//FIXME: if t == 0, idleTime() will now return garbage
+//FIXME: if t == 0, idleTime() will now return garbage
 //	else
 //		d->idleTimer.stop();
+	if(idleChanged)
+		emit idleStateChanged(this);
 }
 
 
@@ -618,7 +597,7 @@ void Contact::setProperty(const Kopete::ContactPropertyTmpl &tmpl,
 		return;
 	}
 
-	if(value.isNull())
+	if(value.isNull() || value.canCast(QVariant::String) && value.toString().isEmpty())
 	{
 		removeProperty(tmpl);
 	}
@@ -626,10 +605,13 @@ void Contact::setProperty(const Kopete::ContactPropertyTmpl &tmpl,
 	{
 		QVariant oldValue = property(tmpl.key()).value();
 
-		Kopete::ContactProperty prop(tmpl, value);
-		d->properties.insert(tmpl.key(), prop, true);
+		if(oldValue != value)
+		{
+			Kopete::ContactProperty prop(tmpl, value);
+			d->properties.insert(tmpl.key(), prop, true);
 
-		emit propertyChanged(this, tmpl.key(), oldValue, value);
+			emit propertyChanged(this, tmpl.key(), oldValue, value);
+		}
 	}
 }
 
@@ -688,7 +670,7 @@ QString Contact::toolTip() const
 			if(!name.isEmpty())
 			{
 				tip += i18n("<br><b>Full Name:</b>&nbsp;FORMATTED NAME",
-					"<br><b>Full Name:</b>&nbsp;<nobr>%1</nobr>").arg(name);
+							"<br><b>Full Name:</b>&nbsp;<nobr>%1</nobr>").arg(QStyleSheet::escape(name));
 			}
 		}
 		else if ((*it) == QString::fromLatin1("FormattedIdleTime"))
@@ -707,7 +689,7 @@ QString Contact::toolTip() const
 			{
 				tip += i18n("<br><b>Home Page:</b>&nbsp;FORMATTED URL",
 					"<br><b>Home Page:</b>&nbsp;<a href=\"%1\"><nobr>%2</nobr></a>").
-					arg( KURL::encode_string( url ), Kopete::Message::escape( url ) );
+						arg( KURL::encode_string( url ), Kopete::Message::escape( QStyleSheet::escape(url) ) );
 			}
 		}
 		else if ((*it) == QString::fromLatin1("awayMessage"))
@@ -716,7 +698,7 @@ QString Contact::toolTip() const
 			if(!awaymsg.isEmpty())
 			{
 				tip += i18n("<br><b>Away Message:</b>&nbsp;FORMATTED AWAY MESSAGE",
-					"<br><b>Away&nbsp;Message:</b>&nbsp;%1").arg ( awaymsg );
+							"<br><b>Away&nbsp;Message:</b>&nbsp;%1").arg ( Kopete::Message::escape(awaymsg) );
 			}
 		}
 		else
@@ -731,23 +713,30 @@ QString Contact::toolTip() const
 				{
 					case QVariant::DateTime:
 						valueText = KGlobal::locale()->formatDateTime(val.toDateTime());
+						valueText = Kopete::Message::escape( valueText );
 						break;
 					case QVariant::Date:
 						valueText = KGlobal::locale()->formatDate(val.toDate());
+						valueText = Kopete::Message::escape( valueText );
 						break;
 					case QVariant::Time:
 						valueText = KGlobal::locale()->formatTime(val.toTime());
+						valueText = Kopete::Message::escape( valueText );
 						break;
 					default:
 						if( p.isRichText() )
+						{
 							valueText = val.toString();
+						}
 						else
+						{
 							valueText = Kopete::Message::escape( val.toString() );
+						}
 				}
 
 				tip += i18n("<br><b>PROPERTY LABEL:</b>&nbsp;PROPERTY VALUE",
 					"<br><nobr><b>%2:</b></nobr>&nbsp;%1").
-					arg( valueText, p.tmpl().label() );
+						arg( valueText, QStyleSheet::escape(p.tmpl().label()) );
 			}
 		}
 	}
@@ -841,10 +830,6 @@ void Kopete::Contact::slotUnblock()
 
 void Kopete::Contact::setNickName( const QString &name )
 {
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
-	if( name == nick )
-		return;
-
 	setProperty( Kopete::Global::Properties::self()->nickName(), name );
 }
 
