@@ -2,7 +2,7 @@
     kopetemessage.cpp  -  Base class for Kopete messages
 
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart @ kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -33,7 +33,7 @@
 #include "kopetemessage.h"
 #include "kopetemetacontact.h"
 #include "kopeteprotocol.h"
-#include "kopetemessagemanager.h"
+#include "kopetechatsession.h"
 #include "kopeteprefs.h"
 #include "kopetecontact.h"
 #include "kopeteemoticons.h"
@@ -68,8 +68,15 @@ public:
 	QColor bgColor;
 	QString body;
 	QString subject;
+	
+	//the cache is used to keep the base64 if images
+	//Note: in QT4 this should be probably a QHash
+	static QMap <QString , QString> imageCache;
+
 };
 
+QMap <QString , QString> Message::Private::imageCache;
+
 Message::Private::Private( const QDateTime &timeStamp, const Contact *from,
              const ContactPtrList &to, const QString &body, const QString &subject,
 				 MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
@@ -224,7 +231,7 @@ void Message::setBody( const QString &body, MessageFormat f )
 		theBody.remove( QString::fromLatin1("\n") );
 	}
 
-	d->body=body;
+	d->body=theBody;
 	d->format = f;
 }
 
@@ -467,7 +474,7 @@ QDomElement Message::contactNode( QDomDocument doc, const Contact *contact )
 
 	// These colors are used for coloring nicknames. I tried to use
 	// colors both visible on light and dark background.
-	static const char* nameColors[] =
+	static const char* const nameColors[] =
 	{
 		"red", "blue" , "gray", "magenta", "violet", "olive", "yellowgreen",
 		"darkred", "darkgreen", "darksalmon", "darkcyan", "darkyellow",
@@ -477,11 +484,11 @@ QDomElement Message::contactNode( QDomDocument doc, const Contact *contact )
 	};
 
 	static const int nameColorsLen = sizeof(nameColors) / sizeof(nameColors[0]) - 1;
-
+	
 	QString contactName = contact->property(Global::Properties::self()->nickName()).value().toString();
 	if( p->truncateContactNames() )
 	{
-		contactName = KStringHandler::csqueeze( contactName, p->maxConactNameLength() );
+		contactName = KStringHandler::csqueeze( contactName, p->maxContactNameLength() );
 	}
 
 	if(contactName.isEmpty())
@@ -503,22 +510,38 @@ QDomElement Message::contactNode( QDomDocument doc, const Contact *contact )
 	                                  QString::fromLatin1("rtl") : QString::fromLatin1("ltr") );
 	metacontactNameNode.setAttribute( QString::fromLatin1("text"), QStyleSheet::escape( metacontactName ) );
 
-	if( contact->metaContact() )
+	
+	if( contact->metaContact() && !contact->metaContact()->metaContactId().isEmpty())
 	{
-		QImage photo = contact->metaContact()->photo();
-		if( !photo.isNull() )
+		if(d->imageCache.contains(contact->metaContact()->metaContactId()))
 		{
-			QByteArray ba;
-			QBuffer buffer( ba );
-			buffer.open( IO_WriteOnly );
-			photo.save ( &buffer, "PNG" );
-			contactNode.setAttribute( QString::fromLatin1("userPhoto"), KCodecs::base64Encode(ba) );
+			contactNode.setAttribute( QString::fromLatin1("userPhoto"), d->imageCache[contact->metaContact()->metaContactId()]);
+		}
+		else
+		{
+			QImage photo = contact->metaContact()->photo();
+			if( !photo.isNull() )
+			{
+				QByteArray ba;
+				QBuffer buffer( ba );
+				buffer.open( IO_WriteOnly );
+				photo.save ( &buffer, "PNG" );
+				QString photo64=KCodecs::base64Encode(ba);
+			
+				if(d->imageCache.count() > 14)
+				{
+					d->imageCache.clear();
+				}
+				d->imageCache.insert(contact->metaContact()->metaContactId(), photo64);
+				
+				contactNode.setAttribute( QString::fromLatin1("userPhoto"), photo64 );
+			}
 		}
 	}
 
 	contactNode.appendChild( metacontactNameNode );
 
-	// FIXME: protocol() returns NULL here in the style preview in appearance config.
+	// protocol() returns NULL here in the style preview in appearance config.
 	// this isn't the right place to work around it, since contacts should never have
 	// no protocol, but it works for now.
 	QString iconName = QString::fromLatin1("kopete");
@@ -532,7 +555,7 @@ QDomElement Message::contactNode( QDomDocument doc, const Contact *contact )
 	int hash = 0;
 	const QString &contactId = contact->contactId();
 	for( uint f = 0; f < contactId.length(); ++f )
-		hash += contactId[f].latin1() * f;
+		hash += contactId[f].unicode() * f;
 
 	QString color = QColor( nameColors[ hash % nameColorsLen ] ).name();
 	contactNode.setAttribute( QString::fromLatin1("color"), color );
@@ -628,6 +651,7 @@ const QDomDocument Message::asXML()
 
 	if( const Contact *c = d->from )
 	{
+		kdDebug() << "KopeteMessage::asXML ** from " << c->contactId() << endl;
 		QDomElement fromNode = doc.createElement( QString::fromLatin1("from") );
 		fromNode.appendChild( contactNode( doc, c ) );
 		messageNode.appendChild( fromNode );
@@ -674,6 +698,7 @@ const QDomDocument Message::asXML()
 	return doc;
 }
 
+// KDE4: Move that to a utils class/namespace
 QString Message::decodeString( const QCString &message, const QTextCodec *providedCodec, bool *success )
 {
 	/*
@@ -694,7 +719,7 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 	charsToCheck = 128 > charsToCheck ? charsToCheck : 128;
 
 	//They are providing a possible codec. Check if it is valid
-	if( providedCodec && providedCodec->heuristicContentMatch( message, charsToCheck ) >= charsToCheck )
+	if( providedCodec && providedCodec->heuristicContentMatch( message, charsToCheck ) >= 0 )
 	{
 		//All chars decodable.
 		return providedCodec->toUnicode( message );
@@ -709,7 +734,7 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 
 	//Try codecForContent - exact match
 	QTextCodec *testCodec = QTextCodec::codecForContent(message, charsToCheck);
-	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= charsToCheck )
+	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= 0 )
 	{
 		//All chars decodable.
 		return testCodec->toUnicode( message );
@@ -723,7 +748,7 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 
 	//Try local codec
 	testCodec = QTextCodec::codecForLocale();
-	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= charsToCheck )
+	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= 0 )
 	{
 		//All chars decodable.
 		kdDebug(14000) << k_funcinfo << "Using locale's codec" << endl;
@@ -732,7 +757,7 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 
 	//Try latin1 codec
 	testCodec = QTextCodec::codecForMib(4);
-	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= charsToCheck )
+	if( testCodec && testCodec->heuristicContentMatch( message, charsToCheck ) >= 0 )
 	{
 		//All chars decodable.
 		kdDebug(14000) << k_funcinfo << "Using latin1" << endl;
@@ -752,3 +777,8 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 	return result;
 }
 
+void Kopete::Message::clearImageCache()  //[static]
+{
+	Private::imageCache.clear();
+}
+
