@@ -4,8 +4,9 @@
     Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
     Copyright (c) 2003 by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2003 by Will Stephenson <lists@stevello.free-online.co.uk>
+    Copyright (c) 2004 by Olivier Goffart <ogoffart @ tiscalinet.be>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -17,31 +18,33 @@
     *************************************************************************
 */
 
-#ifndef __kopeteonlinestatus_h__
-#define __kopeteonlinestatus_h__
+#ifndef kopeteonlinestatus_h
+#define kopeteonlinestatus_h
+
+#include "kopete_export.h"
+
+#include <kdemacros.h>
+#include <ksharedptr.h>
 
 #include <qobject.h>
 
 class QString;
 class QPixmap;
 class QColor;
-class KopeteContact;
-class KopeteAccount;
-
-class KopeteProtocol;
 
 namespace Kopete
 {
-	class OnlineStatusIconCache;
-}
 
-struct KopeteOnlineStatusPrivate;
+	class OnlineStatusManager;
+	class Protocol;
+	class Account;
+	class Contact;
 
 /**
  * @author Martijn Klingens <klingens@kde.org>
  * @author Will Stephenson (icon generating code)
  *
- * KopeteOnlineStatus is a class that encapsulates all information about the
+ * OnlineStatus is a class that encapsulates all information about the
  * various online states that a protocol can be in in a single class. The
  * online status consists of both a 'global' status as it's known to libkopete
  * and used for going online or away, which non-protocol plugins can use,
@@ -56,7 +59,7 @@ struct KopeteOnlineStatusPrivate;
  * to be const after creation as there really shouldn't be a need to change
  * a status' characteristics during runtime!
  */
-class KopeteOnlineStatus
+class KOPETE_EXPORT OnlineStatus
 {
 public:
 	/**
@@ -66,7 +69,7 @@ public:
 	 * should make) a distinction.
 	 * The order is important and is used in the < or > operator
 	 */
-	enum OnlineStatus
+	enum StatusType
 	{
 		/**
 		 * Refers to protocols where state cannot be determined. This
@@ -75,7 +78,7 @@ public:
 		 * to e.g. MSN contacts that are not on your contact list,
 		 * since MSN only allows a user to query online state for
 		 * users that are formally on the contact list. Lastly, libkopete
-		 * itself uses the Unknown state in @ref KopeteMetaContact for
+		 * itself uses the Unknown state in @ref MetaContact for
 		 * meta contacts that have no child contacts at all.
 		 */
 		Unknown=0,
@@ -86,19 +89,19 @@ public:
 		 * that maps to 'Offline', since you're supposed to be
 		 * disconnected from the network in this state.
 		 */
-		Offline=1,
+		Offline=10,
 		/**
 		 * State where the user is not available on the network yet
 		 * but trying to get onto. Most useful to yourself contact, because
 		 * this state means not visible but with network access
 		 */
-		Connecting=2,
+		Connecting=20,
 		/**
-		 * State where you are online but none of your contacts can 
+		 * State where you are online but none of your contacts can
 		 * see that you're online. Useful for all the protocols that support
 		 * being invisible.
 		 */
-		Invisible=3,
+		Invisible=30,
 		/**
 		 * Refers to a state where you can be technically reached, but
 		 * for one reason or another it is often not useful to do so.
@@ -107,32 +110,49 @@ public:
 		 * and don't want to get involved in messaging ('Busy' or 'Do
 		 * not Disturb' for example).
 		 */
-		Away=4,
+		Away=40,
 		/**
 		 * Refers to a true online state, i.e. you can be contacted by
 		 * others both technically and practically. This also applies
 		 * to e.g. ICQ's 'Free for Chat' status.
 		 */
-		Online=5
+		Online=50
 	};
 	// note than Unknown is first, because the metacontact algorithm to detect
 	// the metacontact status from the contact status starts from Unknown, and
 	// takes a contact only if its status is greater
 
 	/**
-	 * Constructor.
+	 * Reserved internal status values
 	 *
-	 * Creates an empty KopeteOnlineStatus object. Since you cannot change
-	 * KopeteOnlineStatus objects that are already created other than by their
-	 * assignment operator, this constructor is only a convenience method
-	 * for use in e.g. class members and local variables.
+	 * Any internal status value > 0x80000000 is reserved for internal
+	 * libkopete use. This enumeration lists the currently known values.
 	 */
-	KopeteOnlineStatus();
+	enum ReservedInternalStatus
+	{
+		/**
+		 * The account this contact belongs to is offline. Used with
+		 * the Unknown StatusType.
+		 */
+		AccountOffline = 0x80000001
+	};
+
 
 	/**
 	 * Constructor.
 	 *
-	 * Creates a new KopeteOnlineStatus object. All fields are mandatory; there
+	 * Creates an empty OnlineStatus object. Since you cannot change
+	 * OnlineStatus objects that are already created other than by their
+	 * assignment operator, this constructor is only a convenience method
+	 * for use in e.g. class members and local variables.
+	 */
+	OnlineStatus();
+
+
+	/**
+	 * Constructor.
+	 *
+	 * Creates a new OnlineStatus object. All fields are mandatory; there
 	 * are no default values. Also, you cannot change the object after creation.
 	 *
 	 * @param status is the global online status as used by libkopete
@@ -143,18 +163,56 @@ public:
 	 * more than once. Weight is also used for picking the most important
 	 * 'Away' status for a protocol when going Away.
 	 * @param protocol is a pointer to the protocol used. This is used when
-	 * comparing two states using @ref operator=().
+	 * comparing two online status objects.
+	 * @param internalStatus is the status as used internally by the protocol.
+	 * This status is usually a lot more fine-grained than the status as used
+	 * by libkopete and should be unique per protocol.
+	 * @param overlayIcons is a list of QStrings which are the name of status
+	 * icons to be used by the KDE icon loader. (Statuses which don't have icons
+	 * to overlay like Online and Offline should use QString::null as icon
+	 * name ).  NOTE if the string is a movie ( *.mng ) it must be the first string in the list.
+	 * TODO: KDE4 sort out movies and overlay icons.
+	 * @param description is a description in e.g. tooltips.
+	 */
+	OnlineStatus( StatusType status, unsigned weight, Protocol *protocol,
+		unsigned internalStatus, const QStringList &overlayIcons, const QString &description );
+
+	/**
+	 * Constructor.
+	 *
+	 * @p Creates a new OnlineStatus object and registers it with the @ref Kopete::OnlineStatusManager.
+	 * Registration allows you to generate a KActionMenu filled with KActions for changing to this OnlineStatus,
+	 * using Kopete::Account::accountMenu().
+	 *
+	 * @p Note that weight has an additional significance for registered protocols when used for menu generation.
+	 *
+	 * All fields are mandatory; there
+	 * are no default values. Also, you cannot change the object after creation.
+	 *
+	 * @param status is the global online status as used by libkopete
+	 * @param weight is the 'weight' of this status. The contact list is
+	 * sorted by status, and by weight within a status. It's not possible to
+	 * 'promote' an Away item to a level above Online, since the status field
+	 * always takes precedence. Weight is used when the same status is used
+	 * more than once. Weight is also used for picking the most important
+	 * 'Away' status for a protocol when going Away. Additionally, Weight determinesis also
+	 * @param protocol is a pointer to the protocol used. This is used when
+	 * comparing two online status objects.
 	 * @param internalStatus is the status as used internally by the protocol.
 	 * This status is usually a lot more fine-grained than the status as used
 	 * by libkopete and should be unique per protocol.
 	 * @param overlayIcon is a string returning the name of the status icon to be
-	 * used by the KDE icon loader. (Online and Offline don't have icon to overlay
-	 * so you should QString::null as icon string)
-	 * @param caption is the description of the status in menus and on buttons.
+	 * used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
+	 * Online and Offline should use QString::null as icon string)
 	 * @param description is a description in e.g. tooltips.
+	 * @param caption is the text of the action in the menu
+	 * @param categories the categories this online status is in
+	 * @param options the options of this online status
+	 * @see Kopete::OnlineStatusManager::registerOnlineStatus for more info about the categories and options parameters
 	 */
-	KopeteOnlineStatus( OnlineStatus status, unsigned weight, KopeteProtocol *protocol,
-		unsigned internalStatus, const QString &overlayIcon, const QString &caption, const QString &description );
+	OnlineStatus( StatusType status, unsigned weight, Protocol *protocol, unsigned internalStatus, const QStringList &overlayIcon,
+		const QString &description, const QString& caption,  unsigned int categories=0x0 , unsigned int options=0x0 );
+
 
 	/**
 	 * Constructor.
@@ -163,7 +221,7 @@ public:
 	 * status are set to zero, the strings and icons are set to the meta contact
 	 * strings.
 	 */
-	KopeteOnlineStatus( OnlineStatus status );
+	OnlineStatus( StatusType status );
 
 	/**
 	 * Copy constructor.
@@ -171,17 +229,17 @@ public:
 	 * Just adds a reference to the refcount. Used to copy around the status
 	 * objects with very little overhead.
 	 */
-	KopeteOnlineStatus( const KopeteOnlineStatus &other );
+	OnlineStatus( const OnlineStatus &other );
 
 	/**
 	 * Destructor.
 	 */
-	~KopeteOnlineStatus();
+	~OnlineStatus();
 
 	/**
 	 * \brief Return the status
 	 */
-	OnlineStatus status() const;
+	StatusType status() const;
 
 	/**
 	 * \brief Return the internal status
@@ -194,39 +252,41 @@ public:
 	unsigned weight() const;
 
 	/**
-	 * \brief Return the icon
+	 * \brief Return the list of overlay icons
 	 */
-	QString overlayIcon() const;
+	QStringList overlayIcons() const;
 
 	/**
 	 * \brief Return the description
 	 */
 	QString description() const;
 
-	/**
-	 * \brief Return the caption
-	 */
-	QString caption() const;
-
 	/**
 	 * \brief Return the protocol this applies to
 	 */
-	KopeteProtocol* protocol() const;
+	Protocol* protocol() const;
 
 	/**
-	 * \brief Return a status icon generated for the given KopeteContact
+	 * @return @c true if this a contact with this status is definitely online,
+	 *         @c false if the contact is Offline, Connecting or Unknown.
+	 */
+	bool isDefinitelyOnline() const;
+
+
+	/**
+	 * \brief Return a status icon generated for the given Contact
 	 *
 	 * This will draw an overlay representing the online status
-	 * of the contact the KopeteOnlineStatus applies to
+	 * of the contact the OnlineStatus applies to
 	 * over the base icon.
 	 * A cache is employed to reduce CPU and memory usage.
 	 * @param contact is the contact the icon should apply to.
 	 * @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
 	 */
-	QPixmap iconFor( const KopeteContact *contact, int size = 16 ) const;
+	QPixmap iconFor( const Contact *contact, int size = 16 ) const;
 
 	/**
-	 * \brief Return the mime source for a status icon generated for the given KopeteContact
+	 * \brief Return the mime source for a status icon generated for the given Contact
 	 *
 	 * This behaves essentially like the method above, except for that
 	 * it returns a mime source string that can be used to render the
@@ -237,23 +297,23 @@ public:
 	 * @param contact is the contact the icon should apply to.
 	 * @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
 	 */
-	QString mimeSourceFor( const KopeteContact *contact, int size = 16 ) const;
+	QString mimeSourceFor( const Contact *contact, int size = 16 ) const;
 
 	/**
-	 * \brief Return a status icon generated for the given KopeteAccount
+	 * \brief Return a status icon generated for the given Account
 	 *
 	 * This will draw an overlay representing the online status
-	 * of the account the KopeteOnlineStatus applies to
+	 * of the account the OnlineStatus applies to
 	 * over the base icon.
 	 * A cache is employed to reduce CPU and memory usage.
 	 * @param account is the account the icon should apply to.
 	 * The account's color causes tinting, if it's plain QColor(), no tinting takes place.
 	 * @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
 	 */
-	QPixmap iconFor( const KopeteAccount *account, int size = 16 ) const;
+	QPixmap iconFor( const Account *account, int size = 16 ) const;
 
 	/**
-	 * \brief Return the mime source for a status icon generated for the given KopeteAccount
+	 * \brief Return the mime source for a status icon generated for the given Account
 	 *
 	 * This behaves essentially like the method above, except for that
 	 * it returns a mime source string that can be used to render the
@@ -265,7 +325,7 @@ public:
 	 * The account's color causes tinting, if it's plain QColor(), no tinting takes place.
 	 * @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
 	 */
-	QString mimeSourceFor( const KopeteAccount *account, int size = 16 ) const;
+	QString mimeSourceFor( const Account *account, int size = 16 ) const;
 
 	/**
 	 * \brief Return a previously rendered status icon for a mime source key
@@ -288,7 +348,7 @@ public:
 	/**
 	 * Assignment operator
 	 */
-	KopeteOnlineStatus & operator=( const KopeteOnlineStatus &other );
+	OnlineStatus & operator=( const OnlineStatus &other );
 
 	/**
 	 * Comparison operator
@@ -296,14 +356,14 @@ public:
 	 * Returns true if both the protocol and the internal status are
 	 * identical.
 	 */
-	bool operator==( const KopeteOnlineStatus &other ) const;
+	bool operator==( const OnlineStatus &other ) const;
 
 	/**
 	 * Comparison operator
 	 *
 	 * This operator works exactly opposite of @ref operator==()
 	 */
-	bool operator!=( const KopeteOnlineStatus &other ) const;
+	bool operator!=( const OnlineStatus &other ) const;
 
 	/**
 	 * Comparison operator
@@ -311,60 +371,45 @@ public:
 	 * Returns true if the status() of this contact is of higher value than the other
 	 * contact or if both statuses are equal and weight() is higher for this contact.
 	 */
-	bool operator>( const KopeteOnlineStatus &other ) const;
+	bool operator>( const OnlineStatus &other ) const;
 
 	/**
 	 * Comparison operator
 	 *
 	 * This operator works exactly opposite of @ref operator>()
 	 */
-	bool operator<( const KopeteOnlineStatus &other ) const;
+	bool operator<( const OnlineStatus &other ) const;
+
+	/**
+	 * \brief returns a QString from a StatusType
+	 *
+	 * Static method to convert a Kopete::OnlineStatus::StatusType to a string to avoid
+	 * many issues when saving StatusType to disk
+	 */
+	 static QString statusTypeToString(OnlineStatus::StatusType status);
+
+	 /**
+	 * \brief returns a StatusType from a QString
+	 *
+	 * Static method to convert a QString representing a StatusType to a StatusType to avoid
+	 * many issues when saving StatusType to disk
+	 */
+	 static OnlineStatus::StatusType statusStringToType(QString& string);
+
+
 
 private:
-	KopeteOnlineStatusPrivate *d;
-	QPixmap cacheLookupByObject( const QString& icon, int size, QColor color, bool idle = false) const;
-	QPixmap cacheLookupByMimeSource( const QString &mimeSource ) const;
-	QString mimeSource( const QString& icon, int size, QColor color, bool idle) const;
-	friend class Kopete::OnlineStatusIconCache;
-};
 
-namespace Kopete
-{
-
-namespace Global
-{
-	OnlineStatusIconCache *onlineStatusIconCache();
-}
-
-/** Caches icons for KopeteOnlineStatus **/
-class OnlineStatusIconCache : public QObject
-{
-	Q_OBJECT
-	OnlineStatusIconCache();
-public:
-	~OnlineStatusIconCache();
-	QPixmap cacheLookupByObject( const KopeteOnlineStatus &statusFor, const QString& icon, int size, QColor color, bool idle = false);
-	QPixmap cacheLookupByMimeSource( const QString &mimeSource );
-	QString fingerprint( const KopeteOnlineStatus &statusFor, const QString& icon, int size, QColor color, bool idle = false);
-
-signals:
-	void iconsChanged();
-
-private slots:
-	void slotIconsChanged();
-
-private:
-	QPixmap* renderIcon( const KopeteOnlineStatus &statusFor, const QString& baseicon, int size, QColor color, bool idle = false) const;
-
-	friend OnlineStatusIconCache *Global::onlineStatusIconCache();
 	class Private;
-	Private *d;
-	QPixmap *nullPixmap;
+	KSharedPtr<Private> d;
+
+	QString mimeSource( const QString& icon, int size, QColor color, bool idle) const;
+
+
 };
 
-}
+}  //END namespace Kopete
 
 #endif
 
-// vim: set noet ts=4 sts=4 sw=4:
 
