@@ -22,14 +22,17 @@
 #include <qptrlist.h>
 #include <qstylesheet.h>
 #include <kplugininfo.h>
+#include <knotification.h>
+#include <kglobal.h>
+#include <kwin.h>
 
-#include "kopetenotifyclient.h"
 #include "kopeteprefs.h"
 #include "kopeteaccount.h"
 #include "kopetepluginmanager.h"
 #include "kopeteviewplugin.h"
-#include "kopetemessagemanagerfactory.h"
+#include "kopetechatsessionmanager.h"
 #include "kopetemetacontact.h"
+#include "kopetenotifyevent.h"
 #include "kopetemessageevent.h"
 #include "kopeteview.h"
 //#include "systemtray.h"
@@ -47,6 +50,10 @@ struct KopeteViewManagerPrivate
 
 	bool useQueue;
 	bool raiseWindow;
+	bool queueUnreadMessages;
+	bool queueOnlyHighlightedMessagesInGroupChats;
+	bool queueOnlyMessagesOnAnotherDesktop;
+	bool balloonNotifyIgnoreClosesChatView;
 	bool foreignMessage;
 };
 
@@ -79,7 +86,7 @@ KopeteViewManager::KopeteViewManager()
 
 KopeteViewManager::~KopeteViewManager()
 {
-	kdDebug(14000) << k_funcinfo << endl;
+// 	kdDebug(14000) << k_funcinfo << endl;
 
 	//delete all open chatwindow.
 	ManagerMap::Iterator it;
@@ -93,11 +100,15 @@ void KopeteViewManager::slotPrefsChanged()
 {
 	d->useQueue = KopetePrefs::prefs()->useQueue();
 	d->raiseWindow = KopetePrefs::prefs()->raiseMsgWindow();
+	d->queueUnreadMessages = KopetePrefs::prefs()->queueUnreadMessages();
+	d->queueOnlyHighlightedMessagesInGroupChats = KopetePrefs::prefs()->queueOnlyHighlightedMessagesInGroupChats();
+	d->queueOnlyMessagesOnAnotherDesktop = KopetePrefs::prefs()->queueOnlyMessagesOnAnotherDesktop();
+	d->balloonNotifyIgnoreClosesChatView = KopetePrefs::prefs()->balloonNotifyIgnoreClosesChatView();
 }
 
 KopeteView *KopeteViewManager::view( Kopete::ChatSession* session, const QString &requestedPlugin )
 {
-	kdDebug(14000) << k_funcinfo << endl;
+// 	kdDebug(14000) << k_funcinfo << endl;
 
 	if( d->managerMap.contains( session ) && d->managerMap[ session ] )
 	{
@@ -146,7 +157,7 @@ KopeteView *KopeteViewManager::view( Kopete::ChatSession* session, const QString
 
 void KopeteViewManager::messageAppended( Kopete::Message &msg, Kopete::ChatSession *manager)
 {
-	kdDebug(14000) << k_funcinfo << endl;
+// 	kdDebug(14000) << k_funcinfo << endl;
 
 	bool outgoingMessage = ( msg.direction() == Kopete::Message::Outbound );
 
@@ -156,32 +167,48 @@ void KopeteViewManager::messageAppended( Kopete::Message &msg, Kopete::ChatSessi
 		manager->view(true,msg.requestedPlugin())->appendMessage( msg );
 		d->foreignMessage=false; //the view is created, reset the flag
 
-		if ( d->useQueue && !view( manager )->isVisible()  )
+		bool appendMessageEvent = d->useQueue;
+
+		QWidget *w;
+		if( d->queueUnreadMessages && ( w = dynamic_cast<QWidget*>(view( manager )) ) )
+		{
+			// append msg event to queue if chat window is active but not the chat view in it...
+			appendMessageEvent &= !(w->isActiveWindow() && manager->view() == d->activeView);
+			// ...and chat window is on another desktop
+			appendMessageEvent &= !d->queueOnlyMessagesOnAnotherDesktop || !KWin::windowInfo( w->topLevelWidget()->winId(), NET::WMDesktop ).isOnCurrentDesktop();
+		}
+		else
+		{
+			// append if no chat window exists already
+			appendMessageEvent &= !view( manager )->isVisible();
+		}
+
+		// in group chats always append highlighted messages to queue
+		appendMessageEvent &= !d->queueOnlyHighlightedMessagesInGroupChats || manager->members().count() == 1 || msg.importance() == Kopete::Message::Highlight;
+
+		if( appendMessageEvent )
 		{
 			if ( !outgoingMessage )
 			{
-
 				Kopete::MessageEvent *event=new Kopete::MessageEvent(msg,manager);
 				d->eventList.append( event );
 				connect(event, SIGNAL(done(Kopete::MessageEvent *)), this, SLOT(slotEventDeleted(Kopete::MessageEvent *)));
 				Kopete::ChatSessionManager::self()->postNewEvent(event);
 			}
 		}
-		else
+		else if( d->eventList.isEmpty() )
 		{
 			readMessages( manager, outgoingMessage );
 		}
 
 		if ( !outgoingMessage && ( !manager->account()->isAway() || KopetePrefs::prefs()->soundIfAway() ) )
 		{
-			int winId = 0;  //KopeteSystemTray::systemTray() ? KopeteSystemTray::systemTray()->winId() : 0;
 			QWidget *w=dynamic_cast<QWidget*>(manager->view(false));
-			if(w) winId=w->topLevelWidget()->winId();
-
 			KConfig *config = KGlobal::config();
 			config->setGroup("General");
-			if( !manager->view(false) || !w || manager->view() != d->activeView ||
-						  config->readBoolEntry("EventIfActive", true) || !w->isActiveWindow() )
+			if( (!manager->view(false) || !w || manager->view() != d->activeView ||
+						   config->readBoolEntry("EventIfActive", true) || !w->isActiveWindow())
+						   && msg.from())
 			{
 				QString msgFrom = QString::null;
 				if( msg.from()->metaContact() )
@@ -208,22 +235,23 @@ void KopeteViewManager::messageAppended( Kopete::Message &msg, Kopete::ChatSessi
 					default:
 						event = QString::fromLatin1( "kopete_contact_incoming" );
 				}
-				KNotifyClient::event(winId,  event, body.arg( QStyleSheet::escape(msgFrom), QStyleSheet::escape(msgText) ), msg.from()->metaContact(),
-					i18n("View") , const_cast<Kopete::Contact*>(msg.from()) , SLOT(execute()) );
+				KNotification *notify=KNotification::event(msg.from()->metaContact() , event, body.arg( QStyleSheet::escape(msgFrom), QStyleSheet::escape(msgText) ), 0, /*msg.from()->metaContact(),*/
+							w , i18n("View") );
+
+				connect(notify,SIGNAL(activated(unsigned int )), manager , SLOT(raiseView()) );
 			}
 		}
 	}
 }
 
-void KopeteViewManager::readMessages( Kopete::ChatSession *manager, bool outgoingMessage )
+void KopeteViewManager::readMessages( Kopete::ChatSession *manager, bool outgoingMessage, bool activate )
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+// 	kdDebug( 14000 ) << k_funcinfo << endl;
 	d->foreignMessage=!outgoingMessage; //let know for the view we are about to create
 	KopeteView *thisView = manager->view( true );
 	d->foreignMessage=false; //the view is created, reset the flag
- 	if( ( outgoingMessage && !thisView->isVisible() ) || d->raiseWindow )
-		thisView->raise();
-
+	if( ( outgoingMessage && !thisView->isVisible() ) || d->raiseWindow || activate )
+		thisView->raise( activate );
 	else if( !thisView->isVisible() )
 		thisView->makeVisible();
 
@@ -242,7 +270,7 @@ void KopeteViewManager::readMessages( Kopete::ChatSession *manager, bool outgoin
 
 void KopeteViewManager::slotEventDeleted( Kopete::MessageEvent *event )
 {
-	kdDebug(14000) << k_funcinfo << endl;
+// 	kdDebug(14000) << k_funcinfo << endl;
 	Kopete::ChatSession *kmm=event->message().manager();
 	if(!kmm)
 		return;
@@ -251,9 +279,9 @@ void KopeteViewManager::slotEventDeleted( Kopete::MessageEvent *event )
 	
 	if ( event->state() == Kopete::MessageEvent::Applied )
 	{
-		readMessages( kmm, false );
+		readMessages( kmm, false, true );
 	}
-	else if ( event->state() == Kopete::MessageEvent::Ignored )
+	else if ( event->state() == Kopete::MessageEvent::Ignored && d->balloonNotifyIgnoreClosesChatView )
 	{
 		bool bAnotherWithThisManager = false;
 		for( QPtrListIterator<Kopete::MessageEvent> it( d->eventList ); it; ++it )
@@ -269,7 +297,7 @@ void KopeteViewManager::slotEventDeleted( Kopete::MessageEvent *event )
 
 void KopeteViewManager::nextEvent()
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+// 	kdDebug( 14000 ) << k_funcinfo << endl;
 
 	if( d->eventList.isEmpty() )
 		return;
@@ -282,7 +310,7 @@ void KopeteViewManager::nextEvent()
 
 void KopeteViewManager::slotViewActivated( KopeteView *view )
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+// 	kdDebug( 14000 ) << k_funcinfo << endl;
 	d->activeView = view;
 
 	QPtrListIterator<Kopete::MessageEvent> it ( d->eventList );
@@ -298,7 +326,7 @@ void KopeteViewManager::slotViewActivated( KopeteView *view )
 
 void KopeteViewManager::slotViewDestroyed( KopeteView *closingView )
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+// 	kdDebug( 14000 ) << k_funcinfo << endl;
 
 	if( d->managerMap.contains( closingView->msgManager() ) )
 	{
@@ -312,7 +340,7 @@ void KopeteViewManager::slotViewDestroyed( KopeteView *closingView )
 
 void KopeteViewManager::slotChatSessionDestroyed( Kopete::ChatSession *manager )
 {
-	kdDebug( 14000 ) << k_funcinfo << endl;
+// 	kdDebug( 14000 ) << k_funcinfo << endl;
 
 	if( d->managerMap.contains( manager ) )
 	{
