@@ -62,9 +62,11 @@ public:
 	void setAway( bool isAway, const QString& awayMessage = QString::null );
 	KActionMenu* actionMenu();
 	void dccRequest( GaduContact* );
-	void sendFile( GaduContact* );
+	void sendFile( GaduContact* , QString& );
 	//}
 	enum tlsConnection{ TLS_ifAvaliable = 0, TLS_only, TLS_no };
+	unsigned int getPersonalInformation();
+	bool publishPersonalInformation( ResLine& d );
 
 public slots:
 	//{
@@ -100,9 +102,7 @@ public slots:
 	// those two functions are connected straight to gadusession ones
 	// with the same names/params. This was the easiest way to
 	// make this interface public
-	bool pubDirSearch( QString& name, QString& surname, QString& nick,
-			    int UIN, QString& city, int gender,
-			    int ageFrom, int ageTo, bool onlyAlive );
+	unsigned int pubDirSearch(  ResLine& query, int ageFrom, int ageTo, bool onlyAlive );
 	void pubDirSearchClose();
 
 	// tls
@@ -114,7 +114,7 @@ public slots:
 	bool setDcc( bool );
 
 signals:
-	void pubDirSearchResult( const SearchResult& );
+	void pubDirSearchResult( const SearchResult&, unsigned int );
 
 protected:
 	//{
@@ -124,7 +124,6 @@ protected:
 
 private slots:
 	void startNotify();
-	void notify( KGaduNotifyList* );
 
 	void messageReceived( KGaduMessage* );
 	void ackReceived( unsigned int );
@@ -138,7 +137,8 @@ private slots:
 
 	void userlist( const QString& contacts );
 	GaduContactsList* userlist();
-
+	void slotUserlistSynch();
+	
 	void connectionFailed( gg_failure_t failure );
 	void connectionSucceed( );
 
@@ -147,7 +147,7 @@ private slots:
 	void slotCommandDone( const QString&, const QString& );
 	void slotCommandError( const QString&, const QString& );
 
-	void slotSearchResult( const SearchResult& result );
+	void slotSearchResult( const SearchResult& result, unsigned int seq );
 	void userListExportDone();
 
 	void slotIncomingDcc( unsigned int );
@@ -157,6 +157,7 @@ private:
 	void initActions();
 	void dccOn();
 	void dccOff();
+	void userlistChanged();
 
 	GaduAccountPrivate* p;
 };
