@@ -24,6 +24,7 @@
 #include <kaction.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 
 #include "gaduaccount.h"
 #include "gaduprotocol.h"
@@ -33,7 +34,7 @@
 #include "gaducontactlist.h"
 #include "gadusession.h"
 
-#include "kopetemessagemanagerfactory.h"
+#include "kopetechatsessionmanager.h"
 #include "kopetegroup.h"
 #include "kopetemetacontact.h"
 #include "kopetestdaction.h"
@@ -43,8 +44,8 @@
 
 using Kopete::UserInfoDialog;
 
-GaduContact::GaduContact( uin_t uin, const QString& name, KopeteAccount* account, KopeteMetaContact* parent )
-: KopeteContact( account, QString::number( uin ), parent ), uin_( uin )
+GaduContact::GaduContact( uin_t uin, const QString& name, Kopete::Account* account, Kopete::MetaContact* parent )
+: Kopete::Contact( account, QString::number( uin ), parent ), uin_( uin )
 {
 	msgManager_ = 0L;
 	account_ = static_cast<GaduAccount*>( account );
@@ -59,12 +60,12 @@ GaduContact::GaduContact( uin_t uin, const QString& name, KopeteAccount* account
 
 	// don't call libkopete functions like these until the object is fully
 	// constructed. all GaduContact construction must be above this point.
-	setFileCapable( false );
+	setFileCapable( true );
 
 	//offline
 	setOnlineStatus( GaduProtocol::protocol()->convertStatus( 0 ) );
 
-	setDisplayName( name );
+	setProperty( Kopete::Global::Properties::self()->nickName(), name );
 }
 
 QString
@@ -86,22 +87,19 @@ GaduContact::uin() const
 }
 
 void
-GaduContact::sendFile( const KURL &sourceURL, const QString &fileName, uint fileSize )
+GaduContact::sendFile( const KURL &sourceURL, const QString &/*fileName*/, uint /*fileSize*/ )
 {
 	QString filePath;
 
-	if ( !sourceURL.isValid () ) {
-		filePath = KFileDialog::getOpenFileName( QString::null , "*", 0L, i18n ( "Kopete File Transfer" ) );
-	}
-	else {
-		filePath = sourceURL.path( -1 );
-	}
+	//If the file location is null, then get it from a file open dialog
+	if( !sourceURL.isValid() )
+		filePath = KFileDialog::getOpenFileName(QString::null, "*", 0l  , i18n("Kopete File Transfer"));
+	else
+		filePath = sourceURL.path(-1);
 
-	QFile file ( filePath );
+	kdDebug(14120) << k_funcinfo << "File chosen to send:" << filePath << endl;
 
-	if ( file.exists () ) {
-	// transfer the bastard
-	}
+	account_->sendFile( this, filePath );
 }
 
 
@@ -122,32 +120,32 @@ GaduContact::changedStatus( KGaduNotify* newstatus )
 	version		= newstatus->version;
 	image_size	= newstatus->image_size;
 
-	// FIXME: finish SENDING through DCC after 3.3
-	setFileCapable( false /* newstatus->fileCap */ );
+	setFileCapable( newstatus->fileCap );
 
 	kdDebug(14100) << "uin:" << uin() << " port: " << remote_port << " remote ip: " <<  remote_ip.ip4Addr() << " image size: " << image_size << "  version: "  << version  << endl;
 
 }
 
-QHostAddress& 
+QHostAddress&
 GaduContact::contactIp()
 {
 	return remote_ip;
 }
-unsigned short 
+
+unsigned short
 GaduContact::contactPort()
 {
 	return remote_port;
 }
 
-KopeteMessageManager*
-GaduContact::manager( bool /* canCreate */ )
+Kopete::ChatSession*
+GaduContact::manager( Kopete::Contact::CanCreateFlags  canCreate  )
 {
-	if ( !msgManager_ ) {
-		msgManager_ = KopeteMessageManagerFactory::factory()->create( account_->myself(), thisContact_, GaduProtocol::protocol() );
-		connect( msgManager_, SIGNAL( messageSent( KopeteMessage&, KopeteMessageManager*) ),
-			 this, SLOT( messageSend( KopeteMessage&, KopeteMessageManager*) ) );
-		connect( msgManager_, SIGNAL( destroyed() ),  this, SLOT( slotMessageManagerDestroyed() ) );
+	if ( !msgManager_ && canCreate ) {
+		msgManager_ = Kopete::ChatSessionManager::self()->create( account_->myself(), thisContact_, GaduProtocol::protocol() );
+		connect( msgManager_, SIGNAL( messageSent( Kopete::Message&, Kopete::ChatSession*) ),
+			 this, SLOT( messageSend( Kopete::Message&, Kopete::ChatSession*) ) );
+		connect( msgManager_, SIGNAL( destroyed() ),  this, SLOT( slotChatSessionDestroyed() ) );
 
 	}
 	kdDebug(14100) << "GaduContact::manager returning:  " << msgManager_ << endl;
@@ -155,7 +153,7 @@ GaduContact::manager( bool /* canCreate */ )
 }
 
 void
-GaduContact::slotMessageManagerDestroyed()
+GaduContact::slotChatSessionDestroyed()
 {
 	msgManager_ = 0L;
 }
@@ -168,13 +166,13 @@ GaduContact::initActions()
 }
 
 void
-GaduContact::messageReceived( KopeteMessage& msg )
+GaduContact::messageReceived( Kopete::Message& msg )
 {
-	manager()->appendMessage( msg );
+	manager(Kopete::Contact::CanCreate)->appendMessage( msg );
 }
 
 void
-GaduContact::messageSend( KopeteMessage& msg, KopeteMessageManager* mgr )
+GaduContact::messageSend( Kopete::Message& msg, Kopete::ChatSession* mgr )
 {
 	if ( msg.plainBody().isEmpty() ) {
 		return;
@@ -235,10 +233,17 @@ GaduContact::slotUserInfo()
 }
 
 void
-GaduContact::slotDeleteContact()
+GaduContact::deleteContact()
 {
-	account_->removeContact( this );
-	deleteLater();
+	if ( account_->isConnected() ) {
+		account_->removeContact( this );
+		deleteLater();
+	}
+	else {
+		KMessageBox::error( Kopete::UI::Global::mainWidget(), 
+				i18n( "<qt>Please go online to remove a contact from your contact list.</qt>" ), 
+				i18n( "Gadu-Gadu Plugin" ));
+	}
 }
 
 void
@@ -268,7 +273,7 @@ GaduContact::setContactDetails( const GaduContactsList::ContactLine* cl )
 GaduContactsList::ContactLine*
 GaduContact::contactDetails()
 {
-	KopeteGroupList		groupList;
+	Kopete::GroupList		groupList;
 	QString			groups;
 
 	GaduContactsList::ContactLine* cl = new GaduContactsList::ContactLine;
@@ -283,15 +288,18 @@ GaduContact::contactDetails()
 	cl->uin		= QString::number( uin_ );
 	cl->displayname	= metaContact()->displayName();
 
+	cl->offlineTo	= false;
+	cl->landline	= QString("");
+
 	groupList = metaContact()->groups();
 
-	KopeteGroup* gr;
+	Kopete::Group* gr;
 	for ( gr = groupList.first (); gr ; gr = groupList.next () ) {
 // if present in any group, don't export to top level
 // FIXME: again, probably bug in libkopete
-// in case of topLevel group, KopeteGroup::displayName() returns "TopLevel" ineasted of just " " or "/"
+// in case of topLevel group, Kopete::Group::displayName() returns "TopLevel" ineasted of just " " or "/"
 // imo TopLevel group should be detected like i am doing that below
-		if ( gr!=KopeteGroup::topLevel() ) {
+		if ( gr!=Kopete::Group::topLevel() ) {
 			groups += gr->displayName()+",";
 		}
 	}
@@ -355,7 +363,7 @@ GaduContact::findBestContactName( const GaduContactsList::ContactLine* cl )
 void
 GaduContact::messageAck()
 {
-	manager()->messageSucceeded();
+	manager(Kopete::Contact::CanCreate)->messageSucceeded();
 }
 
 void
