@@ -755,6 +755,8 @@ void IRCProtocol::editNetworks( const QString &networkName )
 		connect( netConf->newNetwork, SIGNAL( clicked() ), this, SLOT( slotNewNetwork() ) );
 		connect( netConf->renameNetwork, SIGNAL( clicked() ), this, SLOT( slotRenameNetwork() ) );
 		connect( netConf->port, SIGNAL( valueChanged( int ) ), this, SLOT( slotHostPortChanged( int ) ) );
+		connect( netConf->networkList, SIGNAL( doubleClicked ( QListBoxItem * )), SLOT(slotRenameNetwork()));
+				
 	}
 
 	disconnect( netConf->networkList, SIGNAL( selectionChanged() ), this, SLOT( slotUpdateNetworkConfig() ) );
@@ -1185,10 +1187,8 @@ void IRCProtocol::slotMoveServerDown()
 	QValueList<IRCHost*>::iterator pos = selectedNetwork->hosts.find( selectedHost );
 	if( *pos != selectedNetwork->hosts.back() )
 	{
-		QValueList<IRCHost*>::iterator nextPos = pos;
-		nextPos++;
-		selectedNetwork->hosts.insert( nextPos, selectedHost );
-		selectedNetwork->hosts.remove( pos );
+		QValueList<IRCHost*>::iterator nextPos = selectedNetwork->hosts.remove( pos );
+		selectedNetwork->hosts.insert( ++nextPos, selectedHost );
 	}
 
 	unsigned int currentPos = netConf->hostList->currentItem();
