@@ -1,10 +1,10 @@
 /*
     irceditaccountwidget.cpp - IRC Account Widget
 
-    Copyright (c) 2003 by Olivier Goffart  <ogoffart@tiscalinet.be>
-    Copyright (c) 2003 by Jason Keirstead  <jason@keirstead.org>
-
-    Kopete    (c) 2003 by the Kopete developers  <kopete-devel@kde.org>
+    Copyright (c) 2005      by Tommi Rantala  <tommi.rantala@cs.helsinki.fi>
+    Copyright (c) 2003      by Olivier Goffart  <ogoffart @ kde.org>
+    Copyright (c) 2003      by Jason Keirstead  <jason@keirstead.org>
+    Kopete    (c) 2003-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -21,6 +21,7 @@
 #include "ircaccount.h"
 #include "ircusercontact.h"
 #include "ircprotocol.h"
+#include "kcodecaction.h"
 
 #include "kircengine.h"
 
@@ -50,6 +51,7 @@ IRCEditAccountWidget::IRCEditAccountWidget(IRCProtocol *proto, IRCAccount *ident
 {
 	mProtocol = proto;
 
+	// iso latin 1
 	int currentCodec = 4;
 
 	if( account() )
@@ -80,10 +82,6 @@ IRCEditAccountWidget::IRCEditAccountWidget(IRCProtocol *proto, IRCAccount *ident
 		informationReplies->setCurrentItem( config->readNumEntry( "InformationReplies", IRCAccount::ActiveWindow ) - 1 );
 		errorMessages->setCurrentItem( config->readNumEntry( "ErrorMessages", IRCAccount::ActiveWindow ) - 1 );
 
-		account()->setMessageDestinations( serverNotices->currentItem(), serverMessages->currentItem(),
-		informationReplies->currentItem(), errorMessages->currentItem()
-						     );
-
 		QStringList cmds = account()->connectCommands();
 		for( QStringList::Iterator i = cmds.begin(); i != cmds.end(); ++i )
 			new QListViewItem( commandList, *i );
@@ -97,13 +95,12 @@ IRCEditAccountWidget::IRCEditAccountWidget(IRCProtocol *proto, IRCAccount *ident
 	mNickName->setValidator( new QRegExpValidator( QString::fromLatin1("^[^#+&][^\\s]*$"), mNickName ) );
 	mAltNickname->setValidator( new QRegExpValidator( QString::fromLatin1("^[^#+&][^\\s]*$"), mAltNickname ) );
 
-	KCharsets *c = KGlobal::charsets();
-	charset->insertStringList( c->availableEncodingNames() );
+	charset->insertStringList( KCodecAction::supportedEncodings() );
 
-	for( int i = 0; i < charset->count(); ++i )
-	{
-		if( c->codecForName( charset->text(i) )->mibEnum() == currentCodec )
-		{
+	for (int i = 0; i < charset->count(); ++i) {
+		QString encoding = KGlobal::charsets()->encodingForName(charset->text(i));
+		
+		if (KGlobal::charsets()->codecForName(encoding)->mibEnum() == currentCodec) {
 			charset->setCurrentItem( i );
 			break;
 		}
@@ -230,17 +227,20 @@ Kopete::Account *IRCEditAccountWidget::apply()
 
 	if( !account() )
 	{
-		setAccount( new IRCAccount( mProtocol, generateAccountId(networkName) ) );
+		setAccount( new IRCAccount( mProtocol, generateAccountId(networkName), QString::null, networkName, nickName ) );
 
 	}
+	else
+	{
+		account()->setNickName( nickName );
+		account()->setNetwork( networkName );
+	}
 
 	mPasswordWidget->save( &account()->password() );
 
-	account()->setNickName( nickName );
 	account()->setAltNick( mAltNickname->text() );
 	account()->setUserName( mUserName->text() );
 	account()->setRealName( m_realNameLineEdit->text() );
-	account()->setNetwork( networkName );
 	account()->setDefaultPart( partMessage->text() );
 	account()->setDefaultQuit( quitMessage->text() );
 	account()->setAutoShowServerWindow( autoShowServerWindow->isChecked() );
