@@ -21,7 +21,6 @@
 #include <qwidget.h>
 #include <qlayout.h>
 
-#include "xmpp_types.h"
 #include "xmpp_tasks.h"
 
 /**
@@ -31,17 +30,19 @@
 class JabberFormTranslator:public QWidget
 {
 
-  Q_OBJECT public:
-	  JabberFormTranslator (QWidget * parent = 0, const char *name = 0);
-	 ~JabberFormTranslator ();
+Q_OBJECT
 
-	void translate (const Jabber::Form & form, QWidget * widget);
-	  Jabber::Form & resultData ();
+public:
+	JabberFormTranslator (const XMPP::Form & form, QWidget * parent = 0, const char *name = 0);
+	~JabberFormTranslator ();
 
-	  signals:void gatherData (Jabber::Form & form);
+	XMPP::Form & resultData ();
 
-  private:
-	  Jabber::Form privForm;
+signals:
+	void gatherData (XMPP::Form & form);
+
+private:
+	XMPP::Form emptyForm, privForm;
 
 };
 
