@@ -22,6 +22,7 @@
 #include <kfiledialog.h>
 #include "jabberprotocol.h"
 #include "jabberaccount.h"
+#include "jabberclient.h"
 #include "jabberfiletransfer.h"
 #include "jabbergroupchatmanager.h"
 #include "jabbergroupmembercontact.h"
@@ -156,7 +157,8 @@ void JabberGroupContact::handleIncomingMessage (const XMPP::Message & message)
 
 		// convert XMPP::Message into Kopete::Message
 		newMessage = new Kopete::Message ( message.timeStamp (), subContact, contactList, body,
-										 message.subject (), Kopete::Message::Inbound,
+										 message.subject (),
+										 subContact != mManager->myself() ? Kopete::Message::Inbound : Kopete::Message::Outbound,
 										 Kopete::Message::PlainText, viewType );
 	}
 
@@ -273,8 +275,10 @@ void JabberGroupContact::slotChatSessionDeleted ()
 
 	if ( account()->isConnected () )
 	{
-		account()->client()->groupChatLeave ( mRosterItem.jid().host (), mRosterItem.jid().user () );
+		account()->client()->leaveGroupChat ( mRosterItem.jid().host (), mRosterItem.jid().user () );
 	}
+	
+	deleteLater();
 
 }
 
