@@ -4,7 +4,7 @@
                              -------------------
     begin                : Mon Dec 9 2002
     copyright            : (C) 2002-2003 by Till Gerken <till@tantalo.net>
-                           Based on code by Olivier Goffart <ogoffart@tiscalinet.be>
+                           Based on code by Olivier Goffart <ogoffart @ kde.org>
     email                : kopete-devel@kde.org
  ***************************************************************************/
 
@@ -29,12 +29,16 @@
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kpassdlg.h>
+#include <kopetepassword.h>
+#include <kopetepasswordedaccount.h>
 
 #include "kopeteuiglobal.h"
 #include "kopetepasswordwidget.h"
 
+#include "jabberclient.h"
 #include "jabbereditaccountwidget.h"
 #include "jabberregisteraccount.h"
+#include "dlgjabberchangepassword.h"
 
 JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, JabberAccount * ident, QWidget * parent, const char *name)
 						: DlgJabberEditAccountWidget (parent, name), KopeteEditAccountWidget (ident)
@@ -42,40 +46,25 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 
 	m_protocol = proto;
 
-	connect (mID, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
-	connect (mPass, SIGNAL (changed ()), this, SLOT (configChanged ()));
-	connect (mResource, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
-	connect (mPriority, SIGNAL (valueChanged (const QString &)), this, SLOT (configChanged ()));
-	connect (mServer, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
-	connect (mPort, SIGNAL (valueChanged (int)), this, SLOT (configChanged ()));
-
-	connect (cbAutoConnect, SIGNAL (toggled (bool)), this, SLOT (configChanged ()));
-	connect (cbUseSSL, SIGNAL (toggled (bool)), this, SLOT (configChanged ()));
-	connect (cbCustomServer, SIGNAL (toggled (bool)), this, SLOT (configChanged ()));
-	connect (cbAllowPlainTextPassword, SIGNAL (toggled (bool)), this, SLOT (configChanged ()));
-
 	connect (mID, SIGNAL (textChanged (const QString &)), this, SLOT (updateServerField ()));
 	connect (cbCustomServer, SIGNAL (toggled (bool)), this, SLOT (updateServerField ()));
 
 	connect (cbUseSSL, SIGNAL (toggled (bool)), this, SLOT (sslToggled (bool)));
 
-	connect (leLocalIP, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
-	connect (sbLocalPort, SIGNAL (valueChanged (int)), this, SLOT (configChanged ()));
-	connect (leProxyJID, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
+	connect (btnChangePassword, SIGNAL ( clicked() ), this, SLOT ( slotChangePasswordClicked () ));
 
-	
 	if (account())
 	{
-		this->reopen ();
+		// we are working with an existing account
+		reopen ();
 		btnRegister->setEnabled ( false );
 	}
 	else
 	{
+		// this is a new account
+		btnChangePassword->setEnabled ( false );
 		connect (btnRegister, SIGNAL (clicked ()), this, SLOT (registerClicked ()));
 	}
-	QWidget::setTabOrder( mID, mPass->mRemembered );
-	QWidget::setTabOrder( mPass->mRemembered, mPass->mPassword );
-	QWidget::setTabOrder( mPass->mPassword, cbAutoConnect );
 }
 
 JabberEditAccountWidget::~JabberEditAccountWidget ()
@@ -129,6 +118,13 @@ void JabberEditAccountWidget::reopen ()
 
 	leProxyJID->setText (account()->configGroup()->readEntry("ProxyJID", QString::null));
 
+	// Privacy
+	cbSendEvents->setChecked( account()->configGroup()->readBoolEntry("SendEvents", true) );
+	cbSendDeliveredEvent->setChecked( account()->configGroup()->readBoolEntry("SendDeliveredEvent", true) );
+	cbSendDisplayedEvent->setChecked( account()->configGroup()->readBoolEntry("SendDisplayedEvent", true) );
+	cbSendComposingEvent->setChecked( account()->configGroup()->readBoolEntry("SendComposingEvent", true) );
+
+	cbHideSystemInfo->setChecked( account()->configGroup()->readBoolEntry("HideSystemInfo", false) );
 }
 
 Kopete::Account *JabberEditAccountWidget::apply ()
@@ -149,7 +145,7 @@ Kopete::Account *JabberEditAccountWidget::apply ()
 
 	this->writeConfig ();
 
-	static_cast<JabberAccount*>(account())->setS5bPort ( sbLocalPort->value () );
+	static_cast<JabberAccount*>(account())->setS5BServerPort ( sbLocalPort->value () );
 
 	return account();
 }
@@ -181,7 +177,14 @@ void JabberEditAccountWidget::writeConfig ()
 
 	account()->configGroup()->writeEntry("ProxyJID", leProxyJID->text());
 
-	settings_changed = false;
+	// Privacy
+	account()->configGroup()->writeEntry("SendEvents", cbSendEvents->isChecked());
+	account()->configGroup()->writeEntry("SendDeliveredEvent", cbSendDeliveredEvent->isChecked());
+	account()->configGroup()->writeEntry("SendDisplayedEvent", cbSendDisplayedEvent->isChecked());
+	account()->configGroup()->writeEntry("SendComposingEvent", cbSendComposingEvent->isChecked());
+	
+	account()->configGroup()->writeEntry("HideSystemInfo", cbHideSystemInfo->isChecked());
+
 }
 
 bool JabberEditAccountWidget::validateData ()
@@ -199,11 +202,6 @@ bool JabberEditAccountWidget::validateData ()
 	return true;
 }
 
-void JabberEditAccountWidget::configChanged ()
-{
-	settings_changed = true;
-}
-
 void JabberEditAccountWidget::updateServerField ()
 {
 
@@ -236,24 +234,27 @@ void JabberEditAccountWidget::registerClicked ()
 {
 
 	JabberRegisterAccount *registerDlg = new JabberRegisterAccount ( this );
-	connect ( registerDlg, SIGNAL ( okClicked () ), this, SLOT ( slotRegisterOkClicked () ) );
-	connect ( registerDlg, SIGNAL ( cancelClicked () ), this, SLOT ( slotRegisterCancelClicked () ) );
 
 	registerDlg->show ();
 
 }
 
-void JabberEditAccountWidget::slotRegisterOkClicked ()
+void JabberEditAccountWidget::slotChangePasswordClicked ()
 {
 
-	//JabberRegisterAccount *registerDlg = static_cast<JabberRegisterAccount*>( sender () );
+	DlgJabberChangePassword *passwordDlg = new DlgJabberChangePassword ( account (), this );
+
+	connect ( passwordDlg, SIGNAL ( destroyed () ), this, SLOT ( slotChangePasswordFinished () ) );
+
+	passwordDlg->show ();
 
 }
 
-void JabberEditAccountWidget::slotRegisterCancelClicked ()
+void JabberEditAccountWidget::slotChangePasswordFinished ()
 {
 
-	//JabberRegisterAccount *registerDlg = static_cast<JabberRegisterAccount*>( sender () );
+	// in case the password has been changed, we need to update it in the UI
+	reopen ();
 
 }
 
