@@ -78,6 +78,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   : DCOPObject( "KpppIface" ), QWidget(parent, name)
   , acct(0)
   , m_bCmdlAccount (false)
+  , m_bCmdlModem (false)
 {
   tabWindow = 0;
 
@@ -112,6 +113,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   // l1->addWidget(label7, 1, 1); (done in resetmodems())
   modem_c = new QComboBox(false, this);
   label7->setBuddy(connectto_c);
+  m_bModemCShown = false;
 
   connect(modem_c, SIGNAL(activated(int)),
 	  SLOT(newdefaultmodem(int)));
@@ -286,6 +288,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
   m_strCmdlAccount = args->getOption("c");
+  m_strCmdlModem = args->getOption("m");
   m_bQuitOnDisconnect = args->isSet("q");
 
   if(!m_strCmdlAccount.isEmpty()) {
@@ -293,6 +296,21 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
     kdDebug(5002) << "cmdl_account: " << m_bCmdlAccount << endl;
   }
 
+  if(!m_strCmdlModem.isEmpty()) {
+    m_bCmdlModem = true;
+    kdDebug(5002) << "cmdl_modem: " << m_bCmdlModem << endl;
+  }
+
+  if(m_bCmdlModem){
+    bool result = gpppdata.setModem(m_strCmdlModem);
+    if (!result){
+      QString string;
+      string = i18n("No such Modem:\n%1\nFalling back to default").arg(m_strCmdlModem);
+      KMessageBox::error(this, string);
+      m_bCmdlModem = false;
+    }
+  }
+
   if(m_bCmdlAccount){
     bool result = gpppdata.setAccount(m_strCmdlAccount);
     if (!result){
@@ -300,7 +318,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
       string = i18n("No such Account:\n%1").arg(m_strCmdlAccount);
       KMessageBox::error(this, string);
       m_bCmdlAccount = false;
-      this->show();
+      show();
     } else {
       beginConnect();
     }
@@ -486,22 +504,19 @@ void KPPPWidget::resetmodems() {
     modem_c->insertItem(gpppdata.modname());
   }
 
-  int newState = -1;
-  if (count > 1 && modem_c->isHidden()) {
+  if (count > 1 && !m_bModemCShown) {
       l1->addWidget(label7, 1, 1);
       l1->addWidget(modem_c, 1, 2);
-      newState = 1;
-  } else if (modem_c->isShown()){
+      m_bModemCShown = true;
+  } else if (count <= 1 && m_bModemCShown){
       l1->remove(label7);
       l1->remove(modem_c);
-      newState = 0;
-  }
-  if (newState >= 0) {
-      label7->setShown(newState);
-      modem_c->setShown(newState);
-      layout()->invalidate();
-      setFixedSize(sizeHint());
+      m_bModemCShown = false;
   }
+  label7->setShown(m_bModemCShown);
+  modem_c->setShown(m_bModemCShown);     
+  layout()->invalidate();
+  setFixedSize(sizeHint());
 
   //set the default modem
   if(!gpppdata.defaultModem().isEmpty()) {
@@ -607,12 +622,13 @@ void KPPPWidget::sigPPPDDied() {
 		msg += i18n("<p>Exit status: %1").arg(Requester::rq->lastStatus);
 		msg += i18n("</p><p>See 'man pppd' for an explanation of the error "
 			    "codes or take a look at the kppp FAQ on "
-			    "  <a href=http://devel-home.kde.org/~kppp/index.html>"
-			    "http://devel-home.kde.org/~kppp/index.html</a></p>");
+			    "  <a href=\"%1\">%2</a></p>")
+                       .arg("http://developer.kde.org/~kppp/index.html")
+                       .arg("http://developer.kde.org/~kppp/index.html");
 	    }
 	}
 
-	if(KMessageBox::warningYesNo(0, msg, i18n("Error"), KStdGuiItem::ok(), i18n("&Details...")) == KMessageBox::No)
+	if(KMessageBox::warningYesNo(0, msg, i18n("Error"), KStdGuiItem::ok(), i18n("&Details")) == KMessageBox::No)
 	  PPPL_ShowLog();
       } else { /* reconnect on disconnect */
         if(gpppdata.waitCallback())
@@ -706,7 +722,14 @@ void KPPPWidget::beginConnect() {
   }
 #endif
 
-  QFileInfo info2(gpppdata.modemDevice());
+  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+  QString device = "";
+  if (args->isSet("dev"))
+    device = args->getOption("dev");
+  else
+    device = gpppdata.modemDevice();
+
+  QFileInfo info2(device);
 
   if(!info2.exists()){
     QString string;
@@ -714,7 +737,7 @@ void KPPPWidget::beginConnect() {
 		   "your modem device properly "
 		   "and/or adjust the location of the modem device on "
 		   "the modem tab of "
-		   "the setup dialog.").arg(gpppdata.modemDevice());
+		   "the setup dialog.").arg(device);
     KMessageBox::error(this, string);
     return;
   }
@@ -750,7 +773,7 @@ void KPPPWidget::beginConnect() {
     return;
   }
 
-  this->hide();
+  hide();
 
   QString tit = i18n("Connecting to: %1").arg(gpppdata.accname());
   con->setCaption(tit);
@@ -833,8 +856,8 @@ void KPPPWidget::delayedDisconnect() {
   if(m_bQuitOnDisconnect)
     kapp->exit(0);
   else {
-    this->quit_b->setFocus();
-    this->show();
+    quit_b->setFocus();
+    show();
   }
 }
 
@@ -846,10 +869,10 @@ void KPPPWidget::helpbutton() {
 
 void KPPPWidget::quitbutton() {
   if(gpppdata.pppdRunning()) {
-    int ok = KMessageBox::warningYesNo(this,
+    int ok = KMessageBox::warningContinueCancel(this,
 			    i18n("Exiting kPPP will close your PPP Session."),
-			    i18n("Quit kPPP?"));
-    if(ok == KMessageBox::Yes) {
+			    i18n("Quit kPPP?"), KStdGuiItem::quit());
+    if(ok == KMessageBox::Continue) {
       Requester::rq->killPPPDaemon();
 
       // stop the disconnect delay timer
