@@ -7,7 +7,7 @@
 
 /*
  *  OSXvnc Copyright (C) 2001 Dan McGuirk <mcguirk@incompleteness.net>.
- *  Original Xvnc code Copyright (C) 1999 AT&T Laboratories Cambridge.  
+ *  Original Xvnc code Copyright (C) 1999 AT&T Laboratories Cambridge.
  *  All Rights Reserved.
  *
  *  This is free software; you can redistribute it and/or modify
@@ -241,7 +241,7 @@ typedef struct _rfbScreenInfo
      * same time while using the same functions.
      */
     void* screenData;
-  
+
     /* The following two members are used to minimise the amount of unnecessary
        drawing caused by cursor movement.  Whenever any drawing affects the
        part of the screen where the cursor is, the cursor is removed first and
@@ -282,7 +282,7 @@ typedef struct _rfbScreenInfo
     Bool cursorIsDrawn;		    /* TRUE if the cursor is currently drawn */
     Bool dontSendFramebufferUpdate; /* TRUE while removing or drawing the
 				       cursor */
-   
+
     /* additions by libvncserver */
 
     rfbPixelFormat rfbServerFormat;
@@ -336,7 +336,7 @@ typedef struct _rfbScreenInfo
     struct rfbCursor* cursor;
 
     /* the frameBufferhas to be supplied by the serving process.
-     * The buffer will not be freed by 
+     * The buffer will not be freed by
      */
     char* frameBuffer;
     KbdAddEventProcPtr kbdAddEvent;
@@ -372,7 +372,7 @@ typedef void (*rfbTranslateFnType)(char *table, rfbPixelFormat *in,
                                    int width, int height);
 
 
-/* 
+/*
  * vncauth.h - describes the functions provided by the vncauth library.
  */
 
@@ -394,12 +394,13 @@ typedef struct sraRegion* sraRegionPtr;
  */
 
 typedef void (*ClientGoneHookPtr)(struct _rfbClientRec* cl);
+typedef void (*NegotiationFinishedHookPtr)(struct _rfbClientRec* cl);
 
 typedef struct _rfbClientRec {
-  
+
     /* back pointer to the screen */
     rfbScreenInfoPtr screen;
-  
+
     /* private data. You should put any application client specific data
      * into a struct and let clientData point to it. Don't forget to
      * free the struct via clientGoneHook!
@@ -407,8 +408,12 @@ typedef struct _rfbClientRec {
      * This is useful if the IO functions have to behave client specific.
      */
     void* clientData;
+
     ClientGoneHookPtr clientGoneHook;
 
+    /* negotiationFinishedHook is called when the negotiation phase has ended */
+    NegotiationFinishedHookPtr negotiationFinishedHook;
+
     SOCKET sock;
     char *host;
 
@@ -526,9 +531,10 @@ typedef struct _rfbClientRec {
     int softSourceLen;
     rfbSoftCursorSetImage *softCursorImages[rfbSoftCursorMaxImages];
     int nextUnusedSoftCursorImage;
-  
+
     Bool enableLastRectEncoding;   /* client supports LastRect encoding */
     Bool enableSoftCursorUpdates;  /* client supports softcursor updates */
+    Bool disableBackground;        /* client wants to disable background */
     Bool enableCursorShapeUpdates; /* client supports cursor shape updates */
     Bool useRichCursorEncoding;    /* rfbEncodingRichCursor is preferred */
     Bool cursorWasChanged;         /* cursor shape update should be sent */
