@@ -2,34 +2,33 @@
  * Copyright (c) 1983  Regents of the University of California, (c) 1998 David Faure
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ *  Redistribution and use in source and binary forms, with or
+ *    without modification, are permitted provided that the following
+ *    conditions are met:
  *
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ *    - Redistributions of source code must retain the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer.
  *
+ *    - Redistributions in binary form must reproduce the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer in the documentation and/or other materials
+ *      provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY
+ *    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ *    PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
+ *    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ *    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ *    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ *    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ *    IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ *    THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * (BSD License, from kdelibs/doc/common/bsd-license.html)
  */
 
 #include "../includ.h"
@@ -38,7 +37,7 @@
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
-#ifdef HAVE_SYS_TYPES_H 
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_UNISTD_H
@@ -49,7 +48,7 @@
 #include <errno.h>
 #include <netdb.h>
 #include <signal.h>
-#include "../print.h"
+#include "../proto.h"
 #include "../defs.h"
 #include "../readconf.h"
 #include "../process.h"
@@ -66,12 +65,14 @@ ForwMachine::ForwMachine(const NEW_CTL_MSG * mp,
 {
     // Store callee as 'local_user'
     strncpy(local_user, mp->r_name, NEW_NAME_SIZE);
+    local_user[ NEW_NAME_SIZE - 1 ] = '\0';
          // -1 is to be sure to have a '\0' at the end
     // Store caller's name
     strncpy(caller_username, mp->l_name, NEW_NAME_SIZE);
+    caller_username[ NEW_NAME_SIZE - 1 ] = '\0';
     // Store caller's protocol
     callerProtocol = (mp->vers==0) ? talkProtocol : ntalkProtocol;
-    
+
     // Forward method : from string to enumerate
     if (!strcmp(_forwardMethod,"FWA"))
         forwardMethod = FWA;
@@ -83,8 +84,8 @@ ForwMachine::ForwMachine(const NEW_CTL_MSG * mp,
 
     // Get answerer machine address and username
     if (getNames(forward)) {
-        message("-- Talking to %s",answ_user);
-        message("-- On %s",answ_machine_name);
+        ktalk_debug("-- Talking to %s",answ_user);
+        ktalk_debug("-- On %s",answ_machine_name);
         // Create a new talk connection, to the answerer ...
         tcAnsw = new TalkConnection(answ_machine_addr,
                                     answ_user,
@@ -124,6 +125,7 @@ int ForwMachine::getNames(char * forward)
     if (*cp == '\0') {
         /* this is a forward to a local user */
         strncpy(answ_user, forward, NEW_NAME_SIZE);
+        answ_user[ NEW_NAME_SIZE -1 ] = '\0';
         answ_machine_name = new char[strlen(Options.hostname)+1];
 	strcpy(answ_machine_name, Options.hostname); /* set by the daemon */
     } else {
@@ -131,12 +133,14 @@ int ForwMachine::getNames(char * forward)
             /* user@host */
             *cp++ = '\0';
             strncpy(answ_user, forward, NEW_NAME_SIZE);
+            answ_user[ NEW_NAME_SIZE -1 ] = '\0';
 	    answ_machine_name = new char[strlen(cp)+1];
 	    strcpy(answ_machine_name, cp);
         } else {
             /* host.user or host!user or host:user */
             *cp++ = '\0';
             strncpy(answ_user, cp, NEW_NAME_SIZE);
+            answ_user[ NEW_NAME_SIZE -1 ] = '\0';
 	    answ_machine_name = new char[strlen(forward)+1];
 	    strcpy(answ_machine_name, forward);
         }
@@ -144,7 +148,7 @@ int ForwMachine::getNames(char * forward)
 
     struct hostent * hp = gethostbyname(answ_machine_name);
     if (!hp) {
-        syslog(LOG_ERR, "gethostbyname for %s: %m", answ_machine_name);
+        syslog(LOG_ERR, "gethostbyname for %s: %s", answ_machine_name, strerror(errno));
         return 0;
     }
     memcpy(&answ_machine_addr, hp->h_addr, hp->h_length);
@@ -161,7 +165,7 @@ int ForwMachine::isLookupForMe(const NEW_CTL_MSG * mp)
         mp->ctl_addr.sin_addr could be tested but how ?
     */
     if (Options.debug_mode)
-    { 
+    {
         syslog(LOG_DEBUG,"-- mp->l_name : '%s' answerer : '%s' mp->r_name : '%s' caller : '%s'",
                mp->l_name, answ_user, mp->r_name, caller_username);
     }
@@ -175,10 +179,10 @@ char * ForwMachine::findMatch(NEW_CTL_MSG * mp)
 {
     /** Check if there is a forwarding machine on this host,
      * matching answerer = r_name and caller = l_name
-     * Then return the initial callee (local_user), to display in ktalkdlg 
+     * Then return the initial callee (local_user), to display in ktalkdlg
      * This is used by local forwards, and therefore also if NEUBehaviour=1 */
     if (Options.debug_mode)
-    { 
+    {
         syslog(LOG_DEBUG,"-- mp->l_name : '%s' caller : '%s' mp->r_name : '%s' answerer : '%s'",
                mp->l_name, caller_username, mp->r_name, answ_user);
     }
@@ -206,14 +210,16 @@ void ForwMachine::connect_FWT(TalkConnection * tcCaller)
     /** FWT : This is the method in which we take the connection to both
      * clients and send each character received from one side to the other
      * side. This allows to pass a firewall for instance. */
-    message("-- connect_FWT : Waiting for connection from Answerer (%s)", answ_user);
+    /* debug("-- connect_FWT : Waiting for connection from Answerer (%s)", answ_user); */
     if (tcAnsw->accept())
     {
-        message("-- connect_FWT : Trying to connect to Caller (%s)",caller_username);
+        /* debug("-- connect_FWT : Trying to connect to Caller (%s)",caller_username); */
         if (tcCaller->connect())
         {
-            message("-- connect_FWT : Connected to caller (%s)", caller_username);
-            message("-- connect_FWT : Connected to both. Let's go");
+            /*
+            debug("-- connect_FWT : Connected to caller (%s)", caller_username);
+            debug("-- connect_FWT : Connected to both. Let's go"); 
+            */
             int socktC = tcCaller->get_sockt();
             int socktA = tcAnsw->get_sockt();
             int max_sockt = (socktC>socktA) ? socktC : socktA;
@@ -252,7 +258,7 @@ void ForwMachine::connect_FWT(TalkConnection * tcCaller)
                             // i18n() missing
                             sprintf((char *)buf, "Speaking to %s@%s\n", caller_username, hp->h_name);
                             write(socktA, (char *)buf, strlen((char *)buf));
-                        } else message("-- ERROR : Unable to resolve caller_machine_addr !");
+                        } else ktalk_debug("-- ERROR : Unable to resolve caller_machine_addr !");
                     }
                 }
             } // for
@@ -260,31 +266,31 @@ void ForwMachine::connect_FWT(TalkConnection * tcCaller)
     } else syslog(LOG_ERR,"-- FWT : Caller did not connect !");
 }
 
-void ForwMachine::sendResponse(const struct sockaddr target, NEW_CTL_RESPONSE * rp)
+void ForwMachine::sendResponse(const struct talk_addr target, NEW_CTL_RESPONSE * rp)
 {
     if (rp->vers == 0) { // otalk protocol (internal coding for it)
         rp->vers /*type in otalk*/ = rp->type;
         rp->type /*answer in otalk*/ = rp->answer;
     }
-    int cc = sendto(0 /*talkd_sockt*/, (char *) rp,
-                    sizeof (NEW_CTL_RESPONSE), 0, &target,
-                    sizeof (struct sockaddr));
+    int cc = sendto(1 /*talkd_sockt*/, (char *) rp,
+                    sizeof (NEW_CTL_RESPONSE), 0, (struct sockaddr *)&target,
+                    sizeof (struct talk_addr));
     if (cc != sizeof (NEW_CTL_RESPONSE))
-        syslog(LOG_WARNING, "sendto: %m");
+        syslog(LOG_WARNING, "sendto: %s", strerror(errno));
 }
 
 /** processAnnounce is done by a child (to let the daemon process other
  * messages, including ours). Then the child is left running (he only knows the
- * value of answ_id_num) and waits for SIGDELETE to use this value. */ 
+ * value of answ_id_num) and waits for SIGDELETE to use this value. */
 void ForwMachine::processAnnounce()
 {
     if ((pid=fork())==0) // store pid in the parent
     {
         // Send announce to the answerer, and wait for response
-        message("-------------- ForwMachine : sending ANNOUNCE to %s",answ_user);
+        ktalk_debug("-------------- ForwMachine : sending ANNOUNCE to %s",answ_user);
         tcAnsw->ctl_transact(ANNOUNCE, caller_id_num);
         // Copy answer and id_num from the response struct
-        message("-------------- ForwMachine : got a response");
+        ktalk_debug("-------------- ForwMachine : got a response");
         NEW_CTL_RESPONSE rp; // build our response struct
         tcAnsw->getResponseItems(&rp.answer, &answ_id_num, 0L);
         // answ_id_num stores id_num for delete.
@@ -292,7 +298,7 @@ void ForwMachine::processAnnounce()
 	rp.vers = TALK_VERSION;
         rp.id_num = htonl(our_id_num);
 
-        message("Storing response id_num %d",answ_id_num);
+        ktalk_debug("Storing response id_num %d",answ_id_num);
         // Now send the response to the caller
         print_response("-- => response (processAnnounce)", &rp);
         sendResponse(caller_ctl_addr, &rp);
@@ -301,13 +307,13 @@ void ForwMachine::processAnnounce()
         // store static ref to this forwmachine in this child.
         pForwMachine = this;
         // register signal hander
-        if (signal(SIGDELETE,&sig_handler)==SIG_ERR) message("ERROR for SIGUSR2");
-        message("Signal handler registered. Waiting...");
+        if (signal(SIGDELETE,&sig_handler)==SIG_ERR) ktalk_debug("ERROR for SIGUSR2");
+        ktalk_debug("Signal handler registered. Waiting...");
         // infinite loop waiting for signals
         while(1)
             sleep(100);
     }
-    message("Forwmachine started for Announce (now) and Delete (later). pid : %d",pid);
+    ktalk_debug("Forwmachine started for Announce (now) and Delete (later). pid : %d",pid);
     // new_process(); // We DON'T register new process.
     // in case of re-announce, this forwmach will be forgotten.
     // we don't want ktalkd to wait infinitely for it to die, it won't.
@@ -319,8 +325,8 @@ void ForwMachine::processLookup(const NEW_CTL_MSG * mp)
 {
     if (fork()==0)
     { // here we are the child
-        message("------------- Got LOOKUP : send it to caller (%s)", caller_username);
-        // Let's send a LOOK_UP on caller's machine, to make sure he still 
+        ktalk_debug("------------- Got LOOKUP : send it to caller (%s)", caller_username);
+        // Let's send a LOOK_UP on caller's machine, to make sure he still
         // wants to speak to the callee...
         TalkConnection * tcCaller = new TalkConnection(caller_machine_addr,
                                                        caller_username,
@@ -330,25 +336,25 @@ void ForwMachine::processLookup(const NEW_CTL_MSG * mp)
         tcCaller->look_for_invite(0/*no error if no invite*/);
         NEW_CTL_RESPONSE rp;
         tcCaller->getResponseItems(&rp.answer, &rp.id_num, &rp.addr);
-        message("------------- Done. Forward response to answerer");
+        ktalk_debug("------------- Done. Forward response to answerer");
 
 	rp.type = LOOK_UP;
 	rp.vers = mp->vers;
         rp.id_num = htonl(rp.id_num);
         // Now send the response to the answerer
         if (forwardMethod == FWR)
-        {        
+        {
             // with caller's addr copied in the NEW_CTL_RESPONSE (if FWR),
             // so that they can talk to each other.
             /* rp.addr filled by getResponseItems */
-            rp.addr.sa_family = htons(rp.addr.sa_family);
+            rp.addr.ta_family = htons(rp.addr.ta_family);
         }
         else // FWT. (FWA doesn't let us get the LOOK_UP)
         {
             // in this case, we copy in the NEW_CTL_RESPONSE the address
             // of the connection socket set up here for the answerer
             rp.addr = tcAnsw->get_addr();
-            rp.addr.sa_family = htons(AF_INET);
+            rp.addr.ta_family = htons(AF_INET);
         }
         print_response("-- => response (processLookup)", &rp);
         if (forwardMethod == FWT)
@@ -368,8 +374,8 @@ void ForwMachine::processLookup(const NEW_CTL_MSG * mp)
 void ForwMachine::processDelete()
 {
         // Send DELETE to the answerer, and don't wait for response
-        message("-------------- ForwMachine : sending DELETE to %s",answ_user);
-        message("Using resp->id_num %d",answ_id_num);
+        ktalk_debug("-------------- ForwMachine : sending DELETE to %s",answ_user);
+        ktalk_debug("Using resp->id_num %d",answ_id_num);
         tcAnsw->ctl_transact(DELETE, answ_id_num);
         _exit(0); // We exit the child, we have finished.
 }
@@ -380,16 +386,16 @@ int ForwMachine::forwMachProcessLookup(TABLE_ENTRY * table, const NEW_CTL_MSG *
 {
     /** This goes through the table, looking for non-NULL fwm entries.
      * After a cast to (ForwMachine *), the fwm entries allows us to
-     * speak to currently availabe ForwMachines, to handle correctly 
+     * speak to currently availabe ForwMachines, to handle correctly
      * this LOOK_UP */
-    message("-- forwMachProcessLookup(mp,rp)");
-    TABLE_ENTRY *ptr;  
+    ktalk_debug("-- forwMachProcessLookup(mp,rp)");
+    TABLE_ENTRY *ptr;
     for (ptr = table; ptr != 0L; ptr = ptr->next) {
         if (ptr->fwm != 0L)
         {
             ForwMachine * fwm = (ForwMachine *) ptr->fwm;
             if (fwm->isLookupForMe(mp)) {
-                message("-- Found match : id %d", ptr->request.id_num);
+                ktalk_debug("-- Found match : id %d", ptr->request.id_num);
                 fwm->processLookup(mp);
                 return 1;
             }
@@ -403,8 +409,8 @@ int ForwMachine::forwMachProcessLookup(TABLE_ENTRY * table, const NEW_CTL_MSG *
  * Then set callee to the initial callee, to display in ktalkdlg */
 char * ForwMachine::forwMachFindMatch(TABLE_ENTRY * table, NEW_CTL_MSG * mp)
 {
-    message("-- forwMachFindMatch(mp)");
-    TABLE_ENTRY *ptr;  
+    ktalk_debug("-- forwMachFindMatch(mp)");
+    TABLE_ENTRY *ptr;
     char * callee;
     for (ptr = table; ptr != 0L; ptr = ptr->next) {
         if (ptr->fwm != 0L)
@@ -412,7 +418,7 @@ char * ForwMachine::forwMachFindMatch(TABLE_ENTRY * table, NEW_CTL_MSG * mp)
             ForwMachine * fwm = (ForwMachine *) ptr->fwm;
             callee = fwm->findMatch(mp);
             if (callee) {
-                message("-- Found match : id %d", ptr->request.id_num);
+                ktalk_debug("-- Found match : id %d", ptr->request.id_num);
                 return callee;
             }
         }
@@ -422,12 +428,12 @@ char * ForwMachine::forwMachFindMatch(TABLE_ENTRY * table, NEW_CTL_MSG * mp)
 
 void sig_handler(int signum)
 {
-    message("SIGNAL received : %d",signum);
+    ktalk_debug("SIGNAL received : %d",signum);
     ForwMachine * fwm = ForwMachine::getForwMachine();
     fwm->processDelete();
 }
 
-inline void ForwMachine::start(int o_id_num)
+void ForwMachine::start(int o_id_num)
 {
     our_id_num = o_id_num;
     processAnnounce();
